@@ -72,7 +72,7 @@ class Model {
     const double sigmoid_kappa_host;       // Kappa parameter for the sigmoid invasion function (for host dispersal)
     const double sigmoid_sigma_host;       // Sigma parameter for the sigmoid invasion function (for host dispersal)
     const double sigmoid_plateau_host;     // Plateau parameter for the sigmoid invasion function (for host dispersal)
-    const double pI0;                      // Initial inoculum: probability to be I at t=0
+    const Vector3D<double> pI0;         // Initial inoculum as an array of dimensions (Npoly, Npatho, Nhost) with the probability to be I at t=0
     const Vector2D<double> disp_patho_clonal;     // Pathogen dispersal matrix (clonal propagules)
     const Vector2D<double> disp_patho_sex;     // Pathogen dispersal matrix (sexual propagules)
     const Vector2D<double> disp_host;      // Host dispersal matrix
@@ -81,7 +81,7 @@ class Model {
           const int& Ngene, const std::vector<double>& area, const Vector2D<int>& rotation,
           const gsl_rng* random_generator, const std::vector<Cultivar>& cultivars, const std::vector<Gene>& genes,
           const Basic_patho& basic_patho, const Treatment& treatment, const std::vector<Croptype>& croptypes, const double& sigmoid_kappa_host,
-          const double& sigmoid_sigma_host, const double& sigmoid_plateau_host, const double& pI0,
+          const double& sigmoid_sigma_host, const double& sigmoid_plateau_host, const Vector3D<double>& pI0,
           const Vector2D<double>& disp_patho_clonal, const Vector2D<double>& disp_patho_sex, const Vector2D<double>& disp_host, const int& seed);
 
     void dynepi();
@@ -95,9 +95,8 @@ class Model {
                              Vector2D<int>& L, Vector2D<int>& I, Vector2D<int>& R, Vector3D<int>& L2I, Vector3D<int>& I2R, 
                              std::vector<int>& N, std::vector<int>& Nspray, std::vector<int>& t_lastspray, std::vector<int>& TFI);
     Vector3D<int> bottleneck(const int& t, const Vector3D<int>& L, const Vector3D<int>& I,
-                             const Vector2D<int>& activeQR);
+                             const Vector2D<int>& activeQR, const int& year);
     //void dormancy(std::vector<int>& P, const int& year, const int& poly, Vector2D<int>& P_rest, std::vector<int>& P_germ);
-//    void dispersal_old(const Vector2D<int>& H, Vector2D<int>& Hjuv, Vector2D<int>& P, const Vector2D<double>& disp_matrix);
     void dispersal(Vector2D<int>& Propagules, const Vector2D<double>& disp_matrix, const int& Ngeno);
     void mutation(std::vector<int>& P);
     void mutation_locus(const int& patho, const int& trait_mut, Vector2D<int>& PpathoMut);
@@ -146,7 +145,8 @@ class Model {
 
     /* Print parameters in an output .txt file */
     void print_param(const int& seed, const std::vector<double>& mutation_prob, const std::vector<double>& efficiency,
-                     const std::vector<double>& adaptation_cost, const std::vector<double>& tradeoff_strength);
+                     const std::vector<double>& adaptation_cost, const std::vector<double>& relative_advantage, 
+                     const std::vector<double>& tradeoff_strength);
 
     /* Write model output in .txt files and print output on screen */
     void write_HHjuvPLIR(const Vector2D<int>& H, const Vector2D<int>& Hjuv, const Vector2D<int>& P,
@@ -299,7 +299,8 @@ inline std::vector<std::vector<double>> Model::ran_multisample_multivariate_gaus
 //' \item disp_host = vectorised dispersal matrix of the host.
 //' }
 //' @param inits list of initial conditions:\itemize{
-//' \item pI0 = initial probability for the first host (whose index is 0) to be infectious (i.e. state I) at t=0.
+//' \item pI0 = vector of length Npoly*Npatho*Nhost giving the probability to be infectious (i.e. state I) at 
+//' t=0 pr each polygon, pathogen genotype and host.
 //' }
 //' @param seed seed (for random number generation).
 //' @param cultivars_param list of parameters associated with each host genotype (i.e. cultivars) 
@@ -325,8 +326,8 @@ inline std::vector<std::vector<double>> Model::ran_multisample_multivariate_gaus
 //' \item latent_period_var = variance of the latent period duration, 
 //' \item infectious_period_mean = maximal expected duration of the infectious period, 
 //' \item infectious_period_var = variance of the infectious period duration,
-//' \item survival_prob = probability for a propagule to survive the off-season, 
-//' \item repro_sex_prob = probability for an infectious host to reproduce via sex rather than via cloning, 
+//' \item survival_prob = matrix giving the probability for a propagule to survive the off-season, for each croptype (rows) and each year (columns) 
+//' \item repro_sex_prob = vector of probabilities for an infectious host to reproduce via sex rather than via cloning for each timestep, 
 //' \item sigmoid_kappa = kappa parameter of the sigmoid contamination function, 
 //' \item sigmoid_sigma = sigma parameter of the sigmoid contamination function, 
 //' \item sigmoid_plateau = plateau parameter of the sigmoid contamination function,
@@ -345,7 +346,9 @@ inline std::vector<std::vector<double>> Model::ran_multisample_multivariate_gaus
 //' \item Nlevels_aggressiveness = vector of number of adaptation levels related to each resistance gene (i.e. 1 + number 
 //' of required mutations for a pathogenicity gene to fully adapt to the corresponding resistance gene), 
 //' \item adaptation_cost = vector of adaptation penalties paid by pathogen genotypes fully adapted 
-//' to the considered resistance genes on hosts that do not carry this gene, 
+//' to the considered resistance genes on all hosts, 
+//' \item relative_advantage = vector of fitness advantages of a pathogen genotype fully adapted to the resistance genes 
+//' on hosts carrying these genes, relative to those that do not carry these genes,
 //' \item tradeoff_strength = vector of strengths of the trade-off relationships between the level of aggressiveness 
 //' on hosts that do and do not carry the resistance genes.
 //' }
@@ -359,7 +362,7 @@ inline std::vector<std::vector<double>> Model::ran_multisample_multivariate_gaus
 //' \item treatment_application_threshold = vector of thresholds (i.e. disease severity, one for each treated cultivar) above which the treatment is applied
 //' }
 //' 
-//' @details See ?landsepi for details on the model and assumptions. 
+//' @details See \code{?landsepi} for details on the model and assumptions. 
 //' Briefly, the model is stochastic, spatially explicit (the basic spatial unit is an individual field), based on a SEIR
 //' (‘susceptible-exposed-infectious-removed’, renamed HLIR for 'healthy-latent-infectious-removed' to avoid confusions 
 //' with 'susceptible host') structure with a discrete time step. It simulates the spread and 
@@ -390,83 +393,100 @@ inline std::vector<std::vector<double>> Model::ran_multisample_multivariate_gaus
 //' Npoly=2
 //' Npatho=2
 //' area <- c(100000, 100000)
-//' cultivars <- as.list(rbind(loadCultivar(name="Susceptible", type="growingHost")
+//' basic_patho_param <- loadPathogen(disease = "rust")
+//' basic_patho_param$repro_sex_prob <- rep(0, time_param$nTSpY+1)
+//'      cultivars <- as.list(rbind(loadCultivar(name="Susceptible", type="growingHost")
 //' , loadCultivar(name="Resistant", type="growingHost")))
 //' names(cultivars)[names(cultivars)=="cultivarName"] <- "name"
-//' cultivars <- c(cultivars, list(sigmoid_kappa_host=0.002, sigmoid_sigma_host=1.001,
-//'  sigmoid_plateau_host=1, cultivars_genes_list=list(numeric(0),0)))
+//' yield0 <- cultivars$yield_H + as.numeric(cultivars$yield_H==0)
+//' cultivars <- c(cultivars, list(relative_yield_H = as.numeric(cultivars$yield_H / yield0)
+//' , relative_yield_L = as.numeric(cultivars$yield_L / yield0)
+//' , relative_yield_I = as.numeric(cultivars$yield_I / yield0)
+//' , relative_yield_R = as.numeric(cultivars$yield_R / yield0)
+//' , sigmoid_kappa_host=0.002, sigmoid_sigma_host=1.001, sigmoid_plateau_host=1
+//' , cultivars_genes_list=list(numeric(0),0)))
 //' rotation <- data.frame(year_1=c(0,1), year_2=c(0,1), year_3=c(0,1), year_4=c(0,1))
 //' croptypes_cultivars_prop <- data.frame(croptypeID=c(0,1), cultivarID=c(0,1), proportion=c(1,1))
 //' genes <- as.list(loadGene(name="MG", type="majorGene"))
-//'     
+//' treatment=list(treatment_degradation_rate=0.1,
+//' treatment_efficiency=0, 
+//' treatment_timesteps=logical(0),
+//' treatment_cultivars=logical(0),
+//' treatment_cost=0,
+//' treatment_application_threshold = logical(0))
+//'   
 //' ## run simulation
 //' model_landsepi(seed=1,
-//'                time_param = time_param,
-//'                basic_patho_param = loadPathogen(disease = "rust"),
-//'                inits = list(pI0=0.01), area_vector = area,
-//'                dispersal = list(disp_patho_clonal=c(0.99,0.01,0.01,0.99),
-//'                disp_patho_sex=c(1,0,0,1),
-//'                disp_host=c(1,0,0,1)),
-//'                rotation_matrix = as.matrix(rotation),
-//'                croptypes_cultivars_prop = as.matrix(croptypes_cultivars_prop),
-//'                cultivars_param = cultivars, genes_param = genes)  
-//' 
-//' ## Compute outputs
-//' eco_param <- list(yield_perHa = cbind(H = as.numeric(cultivars$yield_H),
-//'              L = as.numeric(cultivars$yield_L),
-//'              I = as.numeric(cultivars$yield_I),
-//'              R = as.numeric(cultivars$yield_R)),
-//'              planting_cost_perHa = as.numeric(cultivars$planting_cost),
-//'              market_value = as.numeric(cultivars$market_value))
-//'             
-//' evol_res <- evol_output(, time_param, Npoly, cultivars, genes)
-//' epid_output(, time_param, Npatho, area, rotation
-//' , croptypes_cultivars_prop, cultivars, eco_param)
-//' 
-//' 
-//' 
-//' 
-//' #### 1-year simulation of a rust epidemic in pure susceptible crop in a single 1-km2 patch ####
-//'## Simulation and pathogen parameters
-//'time_param <- list(Nyears=1, nTSpY=120)
-//'area <- c(1E6)
-//'basic_patho_param = loadPathogen(disease = "rust")
-//'## croptypes, cultivars and genes
-//'rotation <- data.frame(year_1=c(0), year_2=c(0))
-//'croptypes_cultivars_prop <- data.frame(croptypeID=c(0), cultivarID=c(0), proportion=c(1))
-//'cultivars <- as.list(rbind(loadCultivar(name="Susceptible", type="growingHost")))
-//'names(cultivars)[names(cultivars)=="cultivarName"] <- "name"
-//'yield0 <- cultivars$yield_H + as.numeric(cultivars$yield_H==0)
-//'cultivars <- c(cultivars, list(relative_yield_H = as.numeric(cultivars$yield_H / yield0)
-//'     , relative_yield_L = as.numeric(cultivars$yield_L / yield0)
-//'     , relative_yield_I = as.numeric(cultivars$yield_I / yield0)
-//'     , relative_yield_R = as.numeric(cultivars$yield_R / yield0)
-//'     , sigmoid_kappa_host=0.002, sigmoid_sigma_host=1.001, sigmoid_plateau_host=1
-//'     , cultivars_genes_list=list(numeric(0))))
-//'genes <-   list(geneName = character(0) , adaptation_cost = numeric(0)
-//'     , mutation_prob = numeric(0)
-//'     , efficiency = numeric(0) , tradeoff_strength = numeric(0)
-//'     , Nlevels_aggressiveness = numeric(0)
-//'     , age_of_activ_mean = numeric(0) , age_of_activ_var = numeric(0)
-//'     , target_trait = character(0)
-//'     , recombination_sd = numeric(0))
-//'treatment=list(treatment_degradation_rate=0.1
-//'     , treatment_efficiency=0
-//'     , treatment_timesteps=logical(0)
-//'     , treatment_cultivars=logical(0)
-//'     , treatment_cost=0
-//'     , treatment_application_threshold = logical(0))
+//' time_param = time_param,
+//' basic_patho_param = basic_patho_param,
+//' inits = list(pI0=c(0.1, rep(0, 7))),
+//' area_vector = area,
+//' dispersal = list(disp_patho_clonal=c(0.99,0.01,0.01,0.99),
+//' disp_patho_sex=c(1,0,0,1),
+//' disp_host=c(1,0,0,1)),
+//' rotation_matrix = as.matrix(rotation),
+//' croptypes_cultivars_prop = as.matrix(croptypes_cultivars_prop),
+//' cultivars_param = cultivars, 
+//' genes_param = genes,
+//' treatment_param = treatment)
 //'
-//'## run simulation
-//'model_landsepi(seed=1, time_param = time_param
-//'     , basic_patho_param = basic_patho_param
-//'     , inits = list(pI0=5E-4), area_vector = area
-//'     , dispersal = list(disp_patho_clonal=c(1), disp_patho_sex=c(1), disp_host=c(1))
-//'     , rotation_matrix = as.matrix(rotation)
-//'     , treatment_param = treatment
-//'     , croptypes_cultivars_prop = as.matrix(croptypes_cultivars_prop)
-//'     , cultivars_param = cultivars,  genes_param = genes)
-//' }
+//' ## Compute outputs
+//' eco_param <- list(yield_perHa = cbind(H = as.numeric(cultivars$relative_yield_H),
+//' L = as.numeric(cultivars$relative_yield_L),
+//' I = as.numeric(cultivars$relative_yield_I),
+//' R = as.numeric(cultivars$relative_yield_R)),
+//' planting_cost_perHa = as.numeric(cultivars$planting_cost),
+//' market_value = as.numeric(cultivars$market_value))
+//'
+//' evol_res <- evol_output(, time_param, Npoly, cultivars, genes)
+//' epid_res <-  epid_output(, time_param, Npatho, area, rotation
+//' , croptypes_cultivars_prop, cultivars, eco_param, treatment, basic_patho_param)
+//'
+//'
+//'
+//' #### 1-year simulation of a rust epidemic in pure susceptible crop in a single 1-km2 patch ####
+//' ## Simulation and pathogen parameters
+//' time_param <- list(Nyears=1, nTSpY=120)
+//' area <- c(1E6)
+//' basic_patho_param = loadPathogen(disease = "rust")
+//' basic_patho_param$repro_sex_prob <- rep(0, time_param$nTSpY+1)
+//' ## croptypes, cultivars and genes
+//' rotation <- data.frame(year_1=c(0), year_2=c(0))
+//' croptypes_cultivars_prop <- data.frame(croptypeID=c(0), cultivarID=c(0), proportion=c(1))
+//'        cultivars <- as.list(rbind(loadCultivar(name="Susceptible", type="growingHost")))
+//' names(cultivars)[names(cultivars)=="cultivarName"] <- "name"
+//' yield0 <- cultivars$yield_H + as.numeric(cultivars$yield_H==0)
+//' cultivars <- c(cultivars, list(relative_yield_H = as.numeric(cultivars$yield_H / yield0)
+//' , relative_yield_L = as.numeric(cultivars$yield_L / yield0)
+//'     , relative_yield_I = as.numeric(cultivars$yield_I / yield0)
+//' , relative_yield_R = as.numeric(cultivars$yield_R / yield0)
+//' , sigmoid_kappa_host=0.002, sigmoid_sigma_host=1.001, sigmoid_plateau_host=1
+//' , cultivars_genes_list=list(numeric(0))))
+//' genes <-   list(geneName = character(0) , adaptation_cost = numeric(0)
+//' , relative_advantage = numeric(0)
+//' , mutation_prob = numeric(0)
+//' , efficiency = numeric(0) , tradeoff_strength = numeric(0)
+//' , Nlevels_aggressiveness = numeric(0)
+//' , age_of_activ_mean = numeric(0) , age_of_activ_var = numeric(0)
+//' , target_trait = character(0)
+//' , recombination_sd = numeric(0))
+//' treatment=list(treatment_degradation_rate=0.1
+//'                               , treatment_efficiency=0
+//' , treatment_timesteps=logical(0)
+//' , treatment_cultivars=logical(0)
+//' , treatment_cost=0
+//' , treatment_application_threshold = logical(0))
+//' 
+//' ## run simulation
+//' model_landsepi(seed=1, time_param = time_param
+//' , basic_patho_param = basic_patho_param
+//' , inits = list(pI0=5E-4), area_vector = area
+//' , dispersal = list(disp_patho_clonal=c(1), disp_patho_sex=c(1), disp_host=c(1))
+//' , rotation_matrix = as.matrix(rotation)
+//' , treatment_param = treatment
+//'                                 , croptypes_cultivars_prop = as.matrix(croptypes_cultivars_prop)
+//' , cultivars_param = cultivars,  genes_param = genes)
+//'  }
 //' @references Rimbaud L., Papaïx J., Rey J.-F., Barrett L. G. and Thrall P. H. (2018).
 //' Assessing the durability andefficiency of landscape-based strategies to deploy plant 
 //' resistance to pathogens. \emph{PLoS Computational Biology} 14(4):e1006067.
