@@ -48,9 +48,10 @@ void print_d3sum1(FILE* f, const int& z, const int& l, const int& c, const Vecto
 /* Print the parameters in an output .txt file */
 void Model::print_param(const int& seed, const std::vector<double>& mutation_prob,
                         const std::vector<double>& efficiency, const std::vector<double>& adaptation_cost,
-                        const std::vector<double>& tradeoff_strength) {
+                        const std::vector<double>& relative_advantage,const std::vector<double>& tradeoff_strength) {
     std::ofstream param_file("parameters.txt");
     std::ofstream landscape_file("param_landscape.txt");
+    std::ofstream inoculum_file("param_inoculum.txt");
 //    std::ofstream genes_file("param_genes.txt");
     std::ofstream dispPclonal_file("param_disp_patho_clonal.txt");
     std::ofstream dispPsex_file("param_disp_patho_sex.txt");
@@ -62,7 +63,17 @@ void Model::print_param(const int& seed, const std::vector<double>& mutation_pro
     param_file << "\n*****             Seasonality                 *****\n";
     param_file << "Nyears:              " << this->Nyears << "\n";
     param_file << "time_steps_per_year: " << this->time_steps_per_year << "\n";
-    param_file << "pI0:                 " << this->pI0 << "\n";
+    inoculum_file << "pI0 (cultivars in rows, pathogen genotypes in columns)" << "\n";
+    for (int poly=0; poly<this->Npoly; poly++){
+      inoculum_file << "  poly " << poly + 1 << ":\n";
+      for (int host=0; host<this->Nhost; host++){
+        for (int patho=0; patho<this->Npatho; patho++){
+          inoculum_file << pI0[poly][patho][host] << " ";
+        }
+        inoculum_file << "\n";
+      }
+      inoculum_file << "\n";
+    }
 
     param_file << "\n*****     Landscape & deployment strategy     *****\n";
     param_file << "Npoly:               " << this->Npoly << "\n";
@@ -98,28 +109,32 @@ void Model::print_param(const int& seed, const std::vector<double>& mutation_pro
     }
 
     param_file << "\n*****                  Hosts                  *****\n";
-    param_file << "Nhost:               " << this->Nhost << "\n";
+    param_file << "Nhost:                " << this->Nhost << "\n";
     param_file << "cultivars: \n";
     for(int i = 0; i < this->Nhost; i++) {
         param_file << "  cultivar " << i + 1 << ":\n" << this->cultivars[i].to_string();
     }
     param_file << "sigmoid_kappa_host:   " << this->sigmoid_kappa_host << "\n";
     param_file << "sigmoid_sigma_host:   " << this->sigmoid_sigma_host << "\n";
-    param_file << "sigmoid_plateau_host: " << this->sigmoid_plateau_host << "\n";
+    param_file << "sigmoid_plateau_host: " << this->sigmoid_plateau_host << "\n\n";
 
     param_file << "\n*****                  Genes                  *****\n";
     param_file << "Ngene: " << this->Ngene << "\n";
     for(int i = 0; i < Ngene; i++) {
-        param_file << "Gene " << i + 1 << ":\n" << this->genes[i].to_string();
-        param_file << "  mutation_prob:          " << mutation_prob[i] << "\n";
+        param_file << "Gene " << i + 1 << ":\n";
         param_file << "  efficiency:             " << efficiency[i] << "\n";
-        param_file << "  adaptation_cost:           " << adaptation_cost[i] << "\n";
-        param_file << "  tradeoff_strength:      " << tradeoff_strength[i] << "\n\n";
+        param_file << "  mutation_prob:          " << mutation_prob[i] << "\n";
+        param_file << "  adaptation_cost:        " << adaptation_cost[i] << "\n";
+        param_file << "  relative_advantage:     " << relative_advantage[i] << "\n";
+        param_file << "  tradeoff_strength:      " << tradeoff_strength[i] << "\n";
+        param_file << this->genes[i].to_string() << "\n";
     }
     
     param_file << "\n*****                 Pathogen                *****\n";
     param_file << "Npatho: " << this->Npatho << "\n";
-    param_file << "basic_patho:\n" << this->basic_patho.to_string();
+    param_file << "basic_patho:\n" << this->basic_patho.to_string() << "\n";
+    
+    param_file << "\n*****                Treatments                *****\n";
     param_file << "Treatment:\n" << this->treatment.to_string();
 }
 
